@@ -49,6 +49,12 @@ if FOAM_BRANCH_VERSION( "dev", ">=", "010600" ):
     pass
 
 
+#--------------------------------------------------------------------------------------
+if FOAM_REF_VERSION( ">=", "020000" ):
+    from sonicFlux.r2_0_0 import *
+    pass
+
+
 #--------------------------------------------------------------------------------------
 def entry_point():
     try:
